@@ -1724,10 +1724,15 @@ class Datasource:
         mygeneric = Generic()
         int_well_id = self.master.wellmasterdict[str_well_name]
         monthly_volume = self.master._getCase("datasource", "wellmonthly", "well_fk", int_well_id)
-        dict_final = mygeneric.fkChanger(monthly_volume["data"])
-        return dict_final
+        try:
+            dict_final = mygeneric.fkChanger(monthly_volume["data"])
+        except:
+            return monthly_volume
+        results = {}
+        results['data'] = dict_final
+        return results
     
-    def getDailyProduction(self,str_well_name: str):
+    def getDailyProduction(self, str_well_name: str):
         """
         {
             "description": "Function that fetch daily production profile of a given well name",
@@ -1944,6 +1949,7 @@ class Generic:
         """
         dict_fks = {
             "well_fk":"well_name",
+            "well_fk_id": "well_name",
             "field_fk":"field_name",
             "formation_fk":"formation_name"
         }
@@ -1952,7 +1958,8 @@ class Generic:
         df_dict = pd.DataFrame(dict_input)
         str_goal = [item for item in list(df_dict.columns) if "_fk" in item][0]
         #print(f'str_goal: {str_goal}')
-        if str_goal == "well_fk":
+        dict_replace = {}
+        if str_goal == "well_fk" or str_goal == "well_fk_id":
             dict_replace = self.master.ids_wellnames
         elif str_goal == "field_fk":
             dict_replace = self.master.fieldmasterdict_inv
